@@ -9,7 +9,7 @@ import numpy as np
 import yaml
 import os
 import json
-from datacenter_utils.logger import logger
+from logger import logger
 
 
 def read_yaml(file_path, key='pg'):
@@ -123,7 +123,8 @@ class Postgres(object):
                         if isinstance(row[i], pd.Timestamp):
                             row[i] = row[i].datetime()
                         elif isinstance(row[i], str):
-                            row[i] = datetime.strptime(row[i], '%Y-%m-%d %H:%M:%S')
+                            row[i] = datetime.strptime(
+                                row[i], '%Y-%m-%d %H:%M:%S')
                         elif isinstance(row[i], date):
                             pass
                         elif isinstance(row[i], datetime):
@@ -138,7 +139,8 @@ class Postgres(object):
             exclude_values = ['EXCLUDED.{}'.format(i) for i in exclude_columns]
             sql_format = sql.format(t=table_name,
                                     column_str=c_str,
-                                    constraint_columns=','.join(constraint_columns),
+                                    constraint_columns=','.join(
+                                        constraint_columns),
                                     exclude_columns=','.join(exclude_columns),
                                     exclude_values=','.join(exclude_values))
             self.cursor.execute(sql_format, row)
@@ -191,12 +193,14 @@ class Postgres(object):
                 if not date_columns:
                     date_columns = []
                 for dd in date_columns:
-                    sql_str = sql_str.replace('"{}" text'.format(dd), '"{}" date'.format(dd))
+                    sql_str = sql_str.replace(
+                        '"{}" text'.format(dd), '"{}" date'.format(dd))
 
                 if not timestamp_columns:
                     timestamp_columns = []
                 for dd in timestamp_columns:
-                    sql_str = sql_str.replace('"{}" text'.format(dd), '"{}" timestamp'.format(dd))
+                    sql_str = sql_str.replace('"{}" text'.format(
+                        dd), '"{}" timestamp'.format(dd))
 
                 # sql_s = re.findall(r'[^\*/:?\\|<>!]', sql_s, re.S)
                 # sql_s = "".join(sql_s)
@@ -206,11 +210,13 @@ class Postgres(object):
                     add_conflict_sql = '''
                     ALTER TABLE "public"."{t}" ADD CONSTRAINT "{pkey}" PRIMARY KEY ({keys});
                     '''.format(t=table_name, pkey=table_name + '_pkey',
-                               keys=','.join(['"{}"'.format(i) for i in constraint_columns])
+                               keys=','.join(['"{}"'.format(i)
+                                             for i in constraint_columns])
                                )
-                    self.cursor.execute('create table {} ({});'.format(table_name, sql_str))
+                    self.cursor.execute(
+                        'create table {} ({});'.format(table_name, sql_str))
                     self.cursor.execute(add_conflict_sql)
-                    logger.info('create table', sql_str)
+                    logger.info(f'create table: {sql_str}')
             else:
                 if len(column_list) - len(constraint_columns) == 1:
                     sql = '''
@@ -238,7 +244,8 @@ class Postgres(object):
                         if isinstance(row[i], pd.Timestamp):
                             row[i] = row[i].date()
                         elif isinstance(row[i], str):
-                            row[i] = datetime.strptime(row[i], '%Y-%m-%d').date()
+                            row[i] = datetime.strptime(
+                                row[i], '%Y-%m-%d').date()
                         elif isinstance(row[i], date):
                             pass
                         elif isinstance(row[i], datetime):
@@ -250,7 +257,8 @@ class Postgres(object):
                             if isinstance(row[i], pd.Timestamp):
                                 row[i] = row[i].datetime()
                             elif isinstance(row[i], str):
-                                row[i] = datetime.strptime(row[i], '%Y-%m-%d %H:%M:%S')
+                                row[i] = datetime.strptime(
+                                    row[i], '%Y-%m-%d %H:%M:%S')
                             elif isinstance(row[i], date):
                                 pass
                             elif isinstance(row[i], datetime):
@@ -272,13 +280,18 @@ class Postgres(object):
                     for remove_c in constraint_columns:
                         exclude_list.remove(remove_c)
                     exclude_columns = ['"{}"'.format(i) for i in exclude_list]
-                    constraint_columns = ['"{}"'.format(i) for i in constraint_columns]
-                    exclude_values = ['EXCLUDED."{}"'.format(i) for i in exclude_list]
-                    sql_str = sql_str.replace('text', '').replace('date', '').replace('float', '')
+                    constraint_columns = ['"{}"'.format(
+                        i) for i in constraint_columns]
+                    exclude_values = ['EXCLUDED."{}"'.format(
+                        i) for i in exclude_list]
+                    sql_str = sql_str.replace('text', '').replace(
+                        'date', '').replace('float', '')
                 sql_format = sql.format(t=table_name,
                                         column_str=c_str,
-                                        constraint_columns=','.join(constraint_columns),
-                                        exclude_columns=','.join(exclude_columns),
+                                        constraint_columns=','.join(
+                                            constraint_columns),
+                                        exclude_columns=','.join(
+                                            exclude_columns),
                                         exclude_values=','.join(exclude_values))
 
                 self.cursor.execute(sql_format, row)
@@ -374,19 +387,3 @@ class Postgres(object):
         # 指定字符去除
         line2 = re.sub(r"[‘’“”，。？?]", "", line1)
         return line2
-
-
-if __name__ == '__main__':
-    config = dict(database="test",
-                  user="read_write",
-                  password="read_write",
-                  host="10.50.1.236",
-                  port="5432")
-    p = Postgres(conf=config)
-    df = pd.DataFrame({"date": [datetime(2021, 1, 1), datetime(2021, 1, 2)],
-                       "factor_ret": [1.4444, 1.23],
-                       "factor_rankIC": [1.22, 1.23],
-                       "group3_ret": [1.22, 1.23],
-                       "group0_ret": [1.22, 1.23],
-                       })
-    p.upsert_df(df, "stock_hs300_longshort_pred", ['date'], ['date'])
